@@ -38,8 +38,7 @@ class ThreeDModelsAPI(APIClient):
         Args:
             chunk_size (int, optional): Number of 3d models to return in each chunk. Defaults to yielding one model a time.
             published (bool): Filter based on whether or not the model has published revisions.
-            limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
-                to return all items.
+            limit (int, optional): Maximum number of 3d models to return. Defaults to return all items.
 
         Yields:
             Union[ThreeDModel, ThreeDModelList]: yields ThreeDModel one by one if chunk is not specified, else ThreeDModelList objects.
@@ -138,7 +137,7 @@ class ThreeDModelsAPI(APIClient):
         self, item: Union[ThreeDModel, ThreeDModelUpdate, List[Union[ThreeDModel, ThreeDModelList]]]
     ) -> Union[ThreeDModel, ThreeDModelList]:
         """`Update 3d models. <https://docs.cognite.com/api/v1/#operation/update3DModels>`_
-        
+
         Args:
             item (Union[ThreeDModel, ThreeDModelUpdate, List[Union[ThreeDModel, ThreeDModelUpdate]]]): ThreeDModel(s) to update
 
@@ -201,15 +200,14 @@ class ThreeDRevisionsAPI(APIClient):
             model_id (int): Iterate over revisions for the model with this id.
             chunk_size (int, optional): Number of 3d model revisions to return in each chunk. Defaults to yielding one model a time.
             published (bool): Filter based on whether or not the revision has been published.
-            limit (int, optional): Maximum number of assets to return. Defaults to 25. Set to -1, float("inf") or None
-                to return all items.
+            limit (int, optional): Maximum number of 3d model revisions to return. Defaults to return all items.
 
         Yields:
             Union[ThreeDModelRevision, ThreeDModelRevisionList]: yields ThreeDModelRevision one by one if chunk is not
                 specified, else ThreeDModelRevisionList objects.
         """
         return self._list_generator(
-            resource_path=self._RESOURCE_PATH.format(model_id),
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id),
             method="GET",
             chunk_size=chunk_size,
             filter={"published": published},
@@ -234,7 +232,9 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.three_d.revisions.retrieve(model_id=1, id=1)
         """
-        return self._retrieve(resource_path=self._RESOURCE_PATH.format(model_id), id=id)
+        return self._retrieve(
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id), id=id
+        )
 
     def create(
         self, model_id: int, revision: Union[ThreeDModelRevision, List[ThreeDModelRevision]]
@@ -258,7 +258,9 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> my_revision = ThreeDModelRevision(file_id=1)
                 >>> res = c.three_d.revisions.create(model_id=1, revision=my_revision)
         """
-        return self._create_multiple(resource_path=self._RESOURCE_PATH.format(model_id), items=revision)
+        return self._create_multiple(
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id), items=revision
+        )
 
     def list(self, model_id: int, published: bool = False, limit: int = 25) -> ThreeDModelRevisionList:
         """`List 3d model revisions. <https://docs.cognite.com/api/v1/#operation/get3DRevisions>`_
@@ -281,7 +283,7 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> res = c.three_d.revisions.list(model_id=1, published=True, limit=100)
         """
         return self._list(
-            resource_path=self._RESOURCE_PATH.format(model_id),
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id),
             method="GET",
             filter={"published": published},
             limit=limit,
@@ -322,7 +324,9 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> my_update = ThreeDModelRevisionUpdate(id=1).published.set(False).metadata.add({"key": "value"})
                 >>> res = c.three_d.revisions.update(model_id=1, item=my_update)
         """
-        return self._update_multiple(resource_path=self._RESOURCE_PATH.format(model_id), items=item)
+        return self._update_multiple(
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id), items=item
+        )
 
     def delete(self, model_id: int, id: Union[int, List[int]]) -> None:
         """`Delete 3d model revisions. <https://docs.cognite.com/api/v1/#operation/delete3DRevisions>`_
@@ -342,7 +346,11 @@ class ThreeDRevisionsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.three_d.revisions.delete(model_id=1, id=1)
         """
-        self._delete_multiple(resource_path=self._RESOURCE_PATH.format(model_id), ids=id, wrap_ids=True)
+        self._delete_multiple(
+            resource_path=utils._auxiliary.interpolate_and_url_encode(self._RESOURCE_PATH, model_id),
+            ids=id,
+            wrap_ids=True,
+        )
 
     def update_thumbnail(self, model_id: int, revision_id: int, file_id: int) -> None:
         """`Update a revision thumbnail. <https://docs.cognite.com/api/v1/#operation/updateThumbnail>`_
@@ -412,9 +420,6 @@ class ThreeDRevisionsAPI(APIClient):
     ) -> ThreeDNodeList:
         """`Retrieves a list of ancestor nodes of a given node, including itself, in the hierarchy of the 3D model <https://docs.cognite.com/api/v1/#operation/get3DNodeAncestors>`_
 
-        You can also request a specific subtree with the 'nodeId' query parameter and limit the depth of
-        the resulting subtree with the 'depth' query parameter.
-
         Args:
             model_id (int): Id of the model.
             revision_id (int): Id of the revision.
@@ -551,7 +556,7 @@ class ThreeDAssetMappingAPI(APIClient):
         if isinstance(asset_mapping, ThreeDAssetMapping):
             asset_mapping = [asset_mapping]
         chunks = utils._auxiliary.split_into_chunks(
-            [a.dump(camel_case=True) for a in asset_mapping], self._DELETE_LIMIT
+            [ThreeDAssetMapping(a.node_id, a.asset_id).dump(camel_case=True) for a in asset_mapping], self._DELETE_LIMIT
         )
         tasks = [{"url_path": path + "/delete", "json": {"items": chunk}} for chunk in chunks]
         summary = utils._concurrency.execute_tasks_concurrently(self._post, tasks, self._config.max_workers)
